#!/bin/sh
#
# Filters an Apache access_log for use as source
# material for a ten minute load test.
#
# Each step in the process is output to a separate
# file so you can see (using "wc -l" and a little math)
# how many requests are being dropped.
#
# The final file is called tmp7. It will contain
# 2800 requests (an approximation of what goes
# on in a busy ten minutes).
#

# 14th hour of April 1
grep '\[01/Apr/2004:14:' april1.log >tmp1

# Uncomment all of the following six lines to see
# which ten minute interval is the busiest.
# The 14th hour of April 1, in ten minute intervals.
#grep '\[01/Apr/2004:14:0' tmp1 >tmp1.0
#grep '\[01/Apr/2004:14:1' tmp1 >tmp1.1
grep '\[01/Apr/2004:14:2' tmp1 >tmp1.2
grep '\[01/Apr/2004:14:3' tmp1 >tmp1.3
#grep '\[01/Apr/2004:14:4' tmp1 >tmp1.4
#grep '\[01/Apr/2004:14:5' tmp1 >tmp1.5

# Start with twenty minutes of logs and cut back the final
# number to 2800 requests.
cat tmp1.2 tmp1.3 >tmp2

# Only include requests that returned a 200 (OK) response
grep '" \(200\)\|\(302\) ' tmp2 >tmp3

# Remove any Login redirects
grep -v '&mod=Login&' tmp3 >tmp4

# Remove any POST requests
grep -v ' "POST ' tmp4 >tmp5

# Remove any requests that require a query to have been run
grep -v '&query=[^&]' tmp5 >tmp6

# Use the first 2800 requests.
head -2800 tmp6 >tmp7
